@@ -3,8 +3,6 @@ PrincipleBranchTests <- PrincipleBranchAnswers * exp(PrincipleBranchAnswers)
 SecondaryBranchAnswers <- runif(5000, min = -714.96865723796657, max = -1)
 SecondaryBranchTests <- SecondaryBranchAnswers * exp(SecondaryBranchAnswers)
 
-context("Testing lambertW")
-
 test_that("Functions return proper values", {
   expect_equal(lambertW0(PrincipleBranchTests), PrincipleBranchAnswers)
   expect_equal(lambertWm1(SecondaryBranchTests), SecondaryBranchAnswers)
@@ -17,6 +15,12 @@ test_that("Function behaves properly near 0", {
   expect_equal(V0, LV0)
 })
 
+test_that("W0 behaves properly VERY close to 0", {
+  expect_equal(lambertW0(1e-275), 1e-275)
+  expect_equal(lambertW0(7e-48), 7e-48)
+  expect_equal(lambertW0(-3.81e-71), -3.81e-71)
+})
+
 test_that("Function behaves properly near -1/e", {
   expect_equal(lambertW0(-1/exp(1)), -1)
   expect_equal(lambertWm1(-1/exp(1)), -1)
@@ -50,6 +54,6 @@ test_that("NaNs are returned for values outside domain", {
 })
 
 test_that("Integers are converted to reals for principle branch", {
-  expect_equal(lambertW0(c(-1, 0, 1, 2, 3, 4)),
-               lambertW0(c(-1L, 0L, 1L, 2L, 3L, 4L)))
-})
\ No newline at end of file
+  expect_equal(lambertW0(c(-1L, 0L, 1L, 2L, 3L, 4L)),
+               lambertW0(c(-1, 0, 1, 2, 3, 4)))
+})
